@@ -1,6 +1,6 @@
 
 import numpy as np
-from temgymbasic.functions import circular_beam, point_beam, axial_point_beam, x_axial_point_beam
+from functions import circular_beam, point_beam, axial_point_beam, x_axial_point_beam
 from gui import ModelGui
 
 '''This class create the model composed of the specified components, and handles all of the computation
